@@ -3,6 +3,7 @@
 
 #include <QDebug>
 #include <datatypes/message.h>
+#include <widgets/qstatwidget.h>
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
@@ -13,20 +14,36 @@ MainWindow::MainWindow(QWidget *parent) :
     init();
 
     this->sm = new ServiceMgr(this);
+    this->sm->canUpdateAlbums = true;
+    this->sm->canUpdateFeeds = true;
+    this->sm->canUpdateFriends = true;
+    this->sm->canUpdateMessages = true;
 
     imagesPanel = new ImageBrowserPanel(this->usedFont, this->sm, this);
     profilesPanel = new ProfileBrowserPanel(this->usedFont, this->sm, this);
     messagesPanel = new MessageBrowserPanel(this->usedFont, this->sm, this);
     msgComposer = new MessageComposer(this->sm, this);
+    newsPanel = new NewsBrowserPanel(this->sm, this);
 
-    ui->stackedWidget->addWidget(profilesPanel);
-    ui->stackedWidget->addWidget(imagesPanel);
-    ui->stackedWidget->addWidget(messagesPanel);
+    QMap<int, QList<int> > panelTypeMap;
+    int friendIndex = ui->stackedWidget->addWidget(profilesPanel);
+    int albumsIndex = ui->stackedWidget->addWidget(imagesPanel);
+    int messagesIndex = ui->stackedWidget->addWidget(messagesPanel);
+    ui->stackedWidget->addWidget(newsPanel);
     ui->stackedWidget->addWidget(msgComposer);
 
+    panelTypeMap[friendIndex] << qMetaTypeId<Friend>();
+    panelTypeMap[albumsIndex] << qMetaTypeId<Album>() << qMetaTypeId<Photo>() << qMetaTypeId<Friend>();
+    panelTypeMap[messagesIndex] << qMetaTypeId<Message>();
+
+    this->sm->setPanelToTypeMap(panelTypeMap);
+
     connect(this->sm, SIGNAL(errorOccured(QString, QTransport::Action, bool)),
             this, SLOT(gotErrorMsg(QString, QTransport::Action, bool)));
+
     connect(imagesPanel, SIGNAL(openImage(Photo)), this, SLOT(openImage(Photo)));
+    connect(newsPanel, SIGNAL(openImage(Photo)), this, SLOT(openImage(Photo)));
+
     connect(profilesPanel, SIGNAL(showFriendAlbums(Friend)), this,
             SLOT(showFriendAlbums(Friend)));
     connect(profilesPanel, SIGNAL(showFriendMessages(Friend)), this,
@@ -41,6 +58,7 @@ MainWindow::MainWindow(QWidget *parent) :
     connect(msgComposer, SIGNAL(messageSent()), this, SLOT(messageSent()));
     connect(messagesPanel, SIGNAL(editDraftMessage(Message)), this,
             SLOT(editMessage(Message)));
+    connect(ui->stackedWidget, SIGNAL(currentChanged(int)), this->sm, SLOT(changeActivePanel(int)));
 
     // device rotation
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
@@ -86,6 +104,7 @@ void MainWindow::init()
     ui->mainToolBar->addAction(friendAction);
     ui->mainToolBar->addAction(msgAction);
     ui->mainToolBar->addAction(albumAction);
+    ui->mainToolBar->addAction(newsAction);
     ui->mainToolBar->addAction(moreAction);
 }
 
@@ -93,7 +112,7 @@ void MainWindow::createActions()
 {
     bool isShowLabels = true;
 
-#ifdef Q_WS_MAEMO_5
+#if defined(Q_WS_MAEMO_5) || defined(MEEGO_EDITION_HARMATTAN)
     isShowLabels = false;
 #endif
 
@@ -119,6 +138,12 @@ void MainWindow::createActions()
     connect(albumAction, SIGNAL(triggered()), SLOT(onAlbumsTriggered()));
     actionGroup->addAction(albumAction);
 
+    newsAction = new QAction(isShowLabels ? tr("&News") : "", this);
+    newsAction->setIcon(QIcon(":/res/general_rss.png"));
+    newsAction->setCheckable(true);
+    connect(newsAction, SIGNAL(triggered()), SLOT(onNewsTriggered()));
+    actionGroup->addAction(newsAction);
+
     moreAction = new QAction(isShowLabels ? tr("&More") : "", this);
     moreAction->setIcon(QIcon(":/res/more.png"));
     moreAction->setShortcut(QKeySequence(Qt::ALT + Qt::Key_0));
@@ -170,6 +195,8 @@ void MainWindow::createMenus()
    connect(action, SIGNAL(triggered()), this, SLOT(help()));
    action = mainMenu->addAction(tr("&About"));
    connect(action, SIGNAL(triggered()), this, SLOT(about()));
+   action = mainMenu->addAction(tr("Statistics"));
+   connect(action, SIGNAL(triggered()), SLOT(statistics()));
 }
 
 // handler for toolbar actions
@@ -248,6 +275,11 @@ void MainWindow::onAlbumsTriggered()
     ui->stackedWidget->setCurrentIndex(IMAGES_PAGE);
 }
 
+void MainWindow::onNewsTriggered()
+{
+    ui->stackedWidget->setCurrentIndex(NEWS_PAGE);
+}
+
 // More
 void MainWindow::onMoreTriggered()
 {
@@ -296,7 +328,7 @@ void MainWindow::gotErrorMsg(QString errorMsg, QTransport::Action acc, bool isMa
 #endif
     /* Create notification */
     notification = notify_notification_new(APP_NAME,
-        errorMsg.toUtf8().data(), NULL
+        errorMsg.toUtf8().data(), ICONPATH
 #ifndef NOTIFY_VERSION_MORE_7
         ,NULL
 #endif
@@ -347,7 +379,7 @@ void MainWindow::showNotification(QString message)
 #endif
     /* Create notification */
     notification = notify_notification_new(APP_NAME,
-        message.toUtf8().data(), NULL
+        message.toUtf8().data(), ICONPATH
 #ifndef NOTIFY_VERSION_MORE_7
         ,NULL
 #endif
@@ -417,9 +449,9 @@ void MainWindow::replyMessage(Message msg)
 void MainWindow::editMessage(Message msg)
 {
     this->msgComposer->resetMessage();
-    this->msgComposer->setRecepient(msg.recepientList.first().id);
-    this->msgComposer->setTitle(msg.title);
-    this->msgComposer->setMessageBody(msg.text);
+    this->msgComposer->setRecepient(msg.recepientList().first().id);
+    this->msgComposer->setTitle(msg.title());
+    this->msgComposer->setMessageBody(msg.text());
     this->ui->stackedWidget->setCurrentIndex(MSG_COMPOSER_PAGE);
 }
 
@@ -507,3 +539,10 @@ void MainWindow::orientationChanged()
         this->addToolBar(Qt::BottomToolBarArea, ui->mainToolBar);
     }
 }
+
+void MainWindow::statistics()
+{
+    QStatWidget *statWindow = new QStatWidget(this->usedFont, this->sm, this);
+    connect(this->sm, SIGNAL(statsUpdated()), statWindow, SLOT(updateStats()));
+    statWindow->show();
+}
