@@ -14,124 +14,134 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="105"/>
+        <location filename="../src/mainwindow.cpp" line="117"/>
         <source>&amp;Friends</source>
         <translation>&amp;Друзья</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="112"/>
+        <location filename="../src/mainwindow.cpp" line="124"/>
         <source>&amp;Messages</source>
         <translation>&amp;Сообщения</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="119"/>
+        <location filename="../src/mainwindow.cpp" line="131"/>
         <source>&amp;Albums</source>
         <translation>&amp;Альбомы</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="126"/>
+        <location filename="../src/mainwindow.cpp" line="138"/>
+        <source>&amp;News</source>
+        <translation>&amp;Новости</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="144"/>
         <source>&amp;More</source>
         <translation>&amp;Другое</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="139"/>
+        <location filename="../src/mainwindow.cpp" line="157"/>
         <source>&amp;File</source>
         <translation>&amp;Файл</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="140"/>
+        <location filename="../src/mainwindow.cpp" line="158"/>
         <source>Full screen</source>
         <translation>Полноэкранный режим</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="145"/>
+        <location filename="../src/mainwindow.cpp" line="163"/>
         <source>&amp;Upload images</source>
         <translation>&amp;Загрузить фотографии</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="150"/>
+        <location filename="../src/mainwindow.cpp" line="168"/>
         <source>&amp;Exit</source>
         <translation>&amp;Выход</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="157"/>
+        <location filename="../src/mainwindow.cpp" line="175"/>
         <source>&amp;Settings</source>
         <translation>&amp;Настройки</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="160"/>
+        <location filename="../src/mainwindow.cpp" line="178"/>
         <source>Accounts</source>
-        <translation>Настройка учетных записей</translation>
+        <translation>Учетные записи</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="162"/>
+        <location filename="../src/mainwindow.cpp" line="180"/>
         <source>Network</source>
         <translation>Настройка сети</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="164"/>
+        <location filename="../src/mainwindow.cpp" line="182"/>
         <source>Program settings</source>
         <translation>Настройка приложения</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="169"/>
+        <location filename="../src/mainwindow.cpp" line="187"/>
         <source>&amp;Help</source>
         <translation>&amp;Справка</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="172"/>
+        <location filename="../src/mainwindow.cpp" line="190"/>
         <source>Help</source>
         <translation>Справка</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="175"/>
+        <location filename="../src/mainwindow.cpp" line="193"/>
         <source>&amp;About</source>
         <translation>&amp;О программе</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="320"/>
-        <location filename="../src/mainwindow.cpp" line="324"/>
+        <location filename="../src/mainwindow.cpp" line="195"/>
+        <source>Statistics</source>
+        <translation>Статистика</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="345"/>
+        <location filename="../src/mainwindow.cpp" line="349"/>
         <source>Error occured</source>
         <translation>Произошла ошибка</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="371"/>
-        <location filename="../src/mainwindow.cpp" line="375"/>
+        <location filename="../src/mainwindow.cpp" line="396"/>
+        <location filename="../src/mainwindow.cpp" line="400"/>
         <source>Notification</source>
         <translation>Уведомление</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="432"/>
+        <location filename="../src/mainwindow.cpp" line="457"/>
         <source>Your message was saved in Drafts.</source>
         <translation>Ваше сообщение сохранено в Черновиках.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="438"/>
+        <location filename="../src/mainwindow.cpp" line="463"/>
         <source>Your message was successfully sent.</source>
         <translation>Ваше сообщение успешно отправлено.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="444"/>
+        <location filename="../src/mainwindow.cpp" line="469"/>
         <source>Message was deleted.</source>
         <translation>Сообщение удалено.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="474"/>
+        <location filename="../src/mainwindow.cpp" line="499"/>
         <source>/help.html</source>
         <translation>/help_ru.html</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="475"/>
+        <location filename="../src/mainwindow.cpp" line="500"/>
         <source>Help - %1</source>
         <translation>Справка - %1</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="492"/>
+        <location filename="../src/mainwindow.cpp" line="517"/>
         <source>/about.html</source>
         <translation>/about_ru.html</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="493"/>
+        <location filename="../src/mainwindow.cpp" line="518"/>
         <source>About - %1</source>
         <translation>О программе - %1</translation>
     </message>
@@ -172,19 +182,45 @@
         <translation>Настройки</translation>
     </message>
     <message>
-        <location filename="../src/ui/uiapplicationsettings.ui" line="46"/>
+        <location filename="../src/ui/uiapplicationsettings.ui" line="28"/>
         <source>Enable window rotation</source>
         <translation>Включить поворот окна</translation>
     </message>
     <message>
-        <location filename="../src/ui/uiapplicationsettings.ui" line="53"/>
+        <location filename="../src/ui/uiapplicationsettings.ui" line="35"/>
         <source>Enable multi panel mode</source>
         <translation>Включить многопанельный режим</translation>
     </message>
     <message>
-        <location filename="../src/ui/uiapplicationsettings.ui" line="60"/>
+        <location filename="../src/ui/uiapplicationsettings.ui" line="42"/>
+        <source>Group news by author</source>
+        <translation>Объединять новости по автору</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/uiapplicationsettings.ui" line="51"/>
+        <location filename="../src/ui/uiapplicationsettings.cpp" line="44"/>
+        <source>Album directory</source>
+        <translation>Каталог альбома</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/uiapplicationsettings.ui" line="61"/>
+        <source>...</source>
+        <translation>...</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/uiapplicationsettings.ui" line="70"/>
         <source>Clear cache</source>
         <translation>Очистить кэш</translation>
     </message>
+    <message>
+        <location filename="../src/ui/uiapplicationsettings.cpp" line="50"/>
+        <source>Wrong directory</source>
+        <translation>Неправильный каталог</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/uiapplicationsettings.cpp" line="50"/>
+        <source>This directory cannot be used to save photos</source>
+        <translation>Выбранный каталог не может быть использован для сохранения изображений</translation>
+    </message>
 </context>
 </TS>
